@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Patch CPAN modules using Git
-$Git::CPAN::Patch::VERSION = '2.0.0';
+$Git::CPAN::Patch::VERSION = '2.0.1';
 use 5.10.1;
 
 use strict;
@@ -85,10 +85,15 @@ __PACKAGE__->meta->make_immutable;
 
 'end of module Git::CPAN::Patch';
 
-__END__
+=pod
 
-# TODO add back --compose to sendpatch
+=head1 NAME
 
+Git::CPAN::Patch - Patch CPAN modules using Git
+
+=head1 VERSION
+
+version 2.0.1
 
 =head1 SYNOPSIS
 
@@ -174,6 +179,23 @@ L<Git::CPAN::Patch> were first presented in the
 article I<CPAN Patching with Git>, published in
 issue 5.1 of L<The Perl Review|http://theperlreview.com>.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+__END__
+
+# TODO add back --compose to sendpatch
+
+
+
 
