@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::FormatPatch::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Format patches using C<cpan/master> as the origin reference
-$Git::CPAN::Patch::Command::FormatPatch::VERSION = '2.0.0';
+$Git::CPAN::Patch::Command::FormatPatch::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -27,6 +27,16 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Git::CPAN::Patch::Command::FormatPatch - Format patches using C<cpan/master> as the origin reference
+
+=head1 VERSION
+
+version 2.0.1
+
 =head1 SYNOPSIS
 
     % git-cpan format-patch
@@ -47,6 +57,15 @@ L<Git::CPAN::Patch>
 
 L<git-format-patch>
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
