@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Import::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Import a module into a git repository
-$Git::CPAN::Patch::Command::Import::VERSION = '2.0.0';
+$Git::CPAN::Patch::Command::Import::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -269,6 +269,13 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Git::CPAN::Patch::Command::Import - Import a module into a git repository
+
+=head1 VERSION
+
+version 2.0.1
 
 =head1 SYNOPSIS
 
@@ -282,7 +289,6 @@ __END__
     # import the latest version
     git-cpan import
 
-
 =head1 DESCRIPTION
 
 This command is used internally by C<git-cpan-init>, C<git-cpan-update> and
@@ -303,11 +309,10 @@ you have pending work.
 
 =over
 
-=item  --backpan
+=item --backpan
 
 Enables Backpan index fetching (to get the author and release date).
 
-
 =item --check, --nocheck
 
 Explicitly enables/disables version checking.  If version checking is
@@ -338,9 +343,19 @@ Yuval Kogman C<< <nothingmuch@woobling.org> >>
 
 Yanick Champoux C<< <yanick@cpan.org> >>
 
-
 =head1 SEE ALSO
 
 L<Git::CPAN::Patch>
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
