@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Squash::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Combine multiple commits into one patch
-$Git::CPAN::Patch::Command::Squash::VERSION = '2.0.0';
+$Git::CPAN::Patch::Command::Squash::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -51,6 +51,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Git::CPAN::Patch::Command::Squash - Combine multiple commits into one patch
+
+=head1 VERSION
+
+version 2.0.1
+
 =head1 SYNOPSIS
 
     % git-cpan squash temp_submit_branch
@@ -70,3 +78,15 @@ C<git merge --squash> against your head revision. This stages all the files for
 the branch and allows you to create a combined commit in order to send a single
 patch easily.
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
