@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Which::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: reports the repository's module
-$Git::CPAN::Patch::Command::Which::VERSION = '2.0.0';
+$Git::CPAN::Patch::Command::Which::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -27,6 +27,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Git::CPAN::Patch::Command::Which - reports the repository's module
+
+=head1 VERSION
+
+version 2.0.1
+
 =head1 SYNOPSIS
 
     % git-cpan which
@@ -45,4 +53,15 @@ Yuval Kogman C<< <nothingmuch@woobling.org> >>
 
 L<Git::CPAN::Patch>
 
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
