@@ -2,7 +2,7 @@ package Git::CPAN::Patch::Import;
 BEGIN {
   $Git::CPAN::Patch::Import::AUTHORITY = 'cpan:YANICK';
 }
-$Git::CPAN::Patch::Import::VERSION = '2.0.0';
+$Git::CPAN::Patch::Import::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -531,17 +531,39 @@ END
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
-Git::CPAN::Patch::Import - The meat of git-cpan-import
+Git::CPAN::Patch::Import
+
+=head1 VERSION
+
+version 2.0.1
 
 =head1 DESCRIPTION
 
 This is the guts of Git::CPAN::Patch::Import moved here to make it callable
 as a function so git-backpan-init goes faster.
 
+=head1 NAME
+
+Git::CPAN::Patch::Import - The meat of git-cpan-import
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+__END__
+
+
 1;
