@@ -2,7 +2,7 @@ package Git::CPAN::Patch::Release;
 BEGIN {
   $Git::CPAN::Patch::Release::AUTHORITY = 'cpan:YANICK';
 }
-$Git::CPAN::Patch::Release::VERSION = '2.0.0';
+$Git::CPAN::Patch::Release::VERSION = '2.0.1';
 use strict;
 use warnings;
 
@@ -165,3 +165,28 @@ has dist_name => (
 );
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Git::CPAN::Patch::Release
+
+=head1 VERSION
+
+version 2.0.1
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
