@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Role::Git::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: provides access to Git repository
-$Git::CPAN::Patch::Role::Git::VERSION = '2.0.0';
+$Git::CPAN::Patch::Role::Git::VERSION = '2.0.1';
 use strict;
 use warnings;
 
@@ -68,3 +68,28 @@ method first_import {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Git::CPAN::Patch::Role::Git - provides access to Git repository
+
+=head1 VERSION
+
+version 2.0.1
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
