@@ -2,7 +2,7 @@ package Git::CPAN::Patch::Role::Patch;
 BEGIN {
   $Git::CPAN::Patch::Role::Patch::AUTHORITY = 'cpan:YANICK';
 }
-$Git::CPAN::Patch::Role::Patch::VERSION = '2.0.0';
+$Git::CPAN::Patch::Role::Patch::VERSION = '2.0.1';
 use 5.10.0;
 
 use strict;
@@ -59,5 +59,25 @@ method send_emails(@patches) {
 
 __END__
 
+=pod
 
+=head1 NAME
 
+Git::CPAN::Patch::Role::Patch
+
+=head1 VERSION
+
+version 2.0.1
+
+=head1 AUTHOR
+
+Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
